@@ -39,12 +39,6 @@ class AnkiQt(QMainWindow):
         aqt.mw = self
         self.app = app
         self.pm = profileManager
-        # running 2.0 for the first time?
-        if self.pm.meta['firstRun']:
-            # load the new deck user profile
-            self.pm.load(self.pm.profiles()[0])
-            self.pm.meta['firstRun'] = False
-            self.pm.save()
         # init rest of app
         self.safeMode = self.app.queryKeyboardModifiers() & Qt.ShiftModifier
         try:
@@ -62,7 +56,11 @@ class AnkiQt(QMainWindow):
             self.onAppMsg(args[0])
         # Load profile in a timer so we can let the window finish init and not
         # close on profile load error.
-        self.progress.timer(10, self.setupProfile, False, requiresCollection=False)
+        if isWin:
+            fn = self.setupProfileAfterWebviewsLoaded
+        else:
+            fn = self.setupProfile
+        self.progress.timer(10, fn, False, requiresCollection=False)
 
     def setupUI(self):
         self.col = None
@@ -90,6 +88,16 @@ class AnkiQt(QMainWindow):
         self.setupOverview()
         self.setupReviewer()
 
+    def setupProfileAfterWebviewsLoaded(self):
+        for w in (self.web, self.bottomWeb):
+            if not w._domDone:
+                self.progress.timer(10, self.setupProfileAfterWebviewsLoaded, False, requiresCollection=False)
+                return
+            else:
+                w.requiresCol = True
+
+        self.setupProfile()
+
     # Profiles
     ##########################################################################
 
@@ -108,6 +116,12 @@ class AnkiQt(QMainWindow):
             self.closeFires = True
 
     def setupProfile(self):
+        if self.pm.meta['firstRun']:
+            # load the new deck user profile
+            self.pm.load(self.pm.profiles()[0])
+            self.pm.meta['firstRun'] = False
+            self.pm.save()
+
         self.pendingImport = None
         self.restoringBackup = False
         # profile not provided on command line?
@@ -175,9 +189,8 @@ class AnkiQt(QMainWindow):
         return not checkInvalidFilename(str)
 
     def onAddProfile(self):
-        name = getOnlyText(_("Name:"))
+        name = getOnlyText(_("Name:")).strip()
         if name:
-            name = name.strip()
             if name in self.pm.profiles():
                 return showWarning(_("Name exists."))
             if not self.profileNameOk(name):
@@ -187,7 +200,7 @@ class AnkiQt(QMainWindow):
             self.refreshProfilesList()
 
     def onRenameProfile(self):
-        name = getOnlyText(_("New name:"), default=self.pm.name)
+        name = getOnlyText(_("New name:"), default=self.pm.name).strip()
         if not name:
             return
         if name == self.pm.name:
@@ -292,7 +305,7 @@ close the profile or restart Anki."""))
                 if getattr(w, "silentlyClose", None):
                     w.close()
                 else:
-                    showWarning("Window should have been closed: {}".format(w))
+                    print("Window should have been closed: {}".format(w))
 
     def unloadProfileAndExit(self):
         self.unloadProfile(self.cleanupAndExit)
@@ -342,6 +355,7 @@ Debug info:
                 self.col = None
 
             # return to profile manager
+            self.hide()
             self.showProfileManager()
             return False
 
@@ -607,6 +621,13 @@ title="%s" %s>%s</button>''' % (
         self.mainLayout.addWidget(sweb)
         self.form.centralwidget.setLayout(self.mainLayout)
 
+        # force webengine processes to load before cwd is changed
+        if isWin:
+            for o in self.web, self.bottomWeb:
+                o.requiresCol = False
+                o._domReady = False
+                o._page.setContent(bytes("", "ascii"))
+
     def closeAllWindows(self, onsuccess):
         aqt.dialogs.closeAll(onsuccess)
 
@@ -793,6 +814,7 @@ QTreeWidget {
         cid = self.col.undo()
         if cid and self.state == "review":
             card = self.col.getCard(cid)
+            self.col.sched.reset()
             self.reviewer.cardQueue.append(card)
             self.reviewer.nextCard()
             self.maybeEnableUndo()
@@ -1294,7 +1316,8 @@ will be lost. Continue?"""))
     def onAppMsg(self, buf):
         if self.state == "startup":
             # try again in a second
-            return self.progress.timer(1000, lambda: self.onAppMsg(buf), False)
+            return self.progress.timer(1000, lambda: self.onAppMsg(buf), False,
+                                       requiresCollection=False)
         elif self.state == "profileManager":
             # can't raise window while in profile manager
             if buf == "raise":
